print.fcoint: Print Method for fcoint Objects

View source: R/fcoint_fcoint.R

print.fcointR Documentation

Print Method for fcoint Objects

Description

Prints a formatted summary of Fourier cointegration test results.

Usage

## S3 method for class 'fcoint'
print(x, ...)

Arguments

x

An object of class "fcoint".

...

Further arguments passed to or from other methods (unused).

Value

Invisibly returns x.

Examples

set.seed(1)
n <- 60
x <- cumsum(rnorm(n))
y <- 0.5 * x + rnorm(n)
res <- fcoint(y, x, test = "fadl", max_freq = 2)
print(res)

cointests documentation built on March 27, 2026, 5:07 p.m.