View source: R/fcoint_fcoint.R
| print.fcoint | R Documentation |
Prints a formatted summary of Fourier cointegration test results.
## S3 method for class 'fcoint'
print(x, ...)
x |
An object of class |
... |
Further arguments passed to or from other methods (unused). |
Invisibly returns x.
set.seed(1)
n <- 60
x <- cumsum(rnorm(n))
y <- 0.5 * x + rnorm(n)
res <- fcoint(y, x, test = "fadl", max_freq = 2)
print(res)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.